Class: OpenTelemetry::SDK::Configurator::NoopTextMapPropagator Private
- Inherits:
-
Object
- Object
- OpenTelemetry::SDK::Configurator::NoopTextMapPropagator
- Defined in:
- lib/opentelemetry/sdk/configurator.rb
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Instance Method Summary collapse
-
#extract(carrier, context: Context.current, getter: Context::Propagation.text_map_getter) ⇒ Object
private
Returns the passed context unchanged because there is nothing to extract.
-
#fields ⇒ Object
private
Returns an empty list because this propagator does not use carrier fields.
-
#inject(carrier, context: Context.current, setter: Context::Propagation.text_map_setter) ⇒ Object
private
No-op because this propagator does not inject any values.
Instance Method Details
#extract(carrier, context: Context.current, getter: Context::Propagation.text_map_getter) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns the passed context unchanged because there is nothing to extract.
21 22 23 |
# File 'lib/opentelemetry/sdk/configurator.rb', line 21 def extract(carrier, context: Context.current, getter: Context::Propagation.text_map_getter) context end |
#fields ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns an empty list because this propagator does not use carrier fields.
26 27 28 |
# File 'lib/opentelemetry/sdk/configurator.rb', line 26 def fields EMPTY_LIST end |
#inject(carrier, context: Context.current, setter: Context::Propagation.text_map_setter) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
No-op because this propagator does not inject any values.
18 |
# File 'lib/opentelemetry/sdk/configurator.rb', line 18 def inject(carrier, context: Context.current, setter: Context::Propagation.text_map_setter); end |